# Work

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDate**](CreatedDate.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDate**](LastModifiedDate.md) |  | [optional] 
**source** | [**Source**](Source.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**title** | [**WorkTitle**](WorkTitle.md) |  | [optional] 
**journal_title** | [**Title**](Title.md) |  | [optional] 
**short_description** | **str** |  | [optional] 
**citation** | [**Citation**](Citation.md) |  | [optional] 
**type** | **str** |  | [optional] 
**publication_date** | [**PublicationDate**](PublicationDate.md) |  | [optional] 
**external_ids** | [**ExternalIDs**](ExternalIDs.md) |  | [optional] 
**url** | [**Url**](Url.md) |  | [optional] 
**contributors** | [**WorkContributors**](WorkContributors.md) |  | [optional] 
**language_code** | **str** |  | [optional] 
**country** | [**Country**](Country.md) |  | [optional] 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


